@@ -6,7 +6,6 @@ from asyncio import AbstractEventLoop
 from typing import Optional, Union
 
 from aiologger import settings
-from aiologger.utils import loop_compat
 from aiologger.filters import Filterer
 from aiologger.formatters.base import Formatter
 from aiologger.formatters.json import JsonFormatter
@@ -18,7 +17,6 @@ from aiologger.records import LogRecord
 _default_formatter = Formatter()
 
 
-@loop_compat
 class Handler(Filterer):
     """
     Handler instances dispatch logging events to specific destinations.
