@@ -17,10 +17,9 @@ from aiofiles.threadpool import AsyncTextIOWrapper
 
 from aiologger.handlers.base import Handler
 from aiologger.records import LogRecord
-from aiologger.utils import classproperty, get_running_loop, loop_compat
+from aiologger.utils import classproperty, get_running_loop
 
 
-@loop_compat
 class AsyncFileHandler(Handler):
     terminator = "\n"
 
@@ -409,11 +408,10 @@ class AsyncTimedRotatingFileHandler(BaseAsyncRotatingFileHandler):
 
     async def _delete_files(self, file_paths: List[str]):
         loop = get_running_loop()
-        delete_tasks = (
-            loop.run_in_executor(None, lambda: os.unlink(file_path))
-            for file_path in file_paths
-        )
-        await asyncio.gather(*delete_tasks)
+        for file_path in file_paths:
+            await loop.run_in_executor(  # type: ignore
+                None, lambda: os.unlink(file_path)
+            )
 
     async def do_rollover(self):
         """
